package com.jesusbianco;

import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.dao.DataAccessException;
import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.scheduling.annotation.EnableAsync;


@SpringBootApplication
@EnableAsync
public class Application {

	private static final Logger logger = LoggerFactory.getLogger(Application.class);
	
	public static void main(String[] args) {
		
		SpringApplication.run(Application.class, args);
		
		logger.info("-- Application Started (Spring Boot v3) --");

		String javaVersion = System.getProperty("java.version");
		logger.info("-- Java Version: " + javaVersion + " --");

		JdbcTemplate jdbcTemplate = new JdbcTemplate( Utilities.getMySQLDataSourceConnectionPool() );

		try {

			Map<String, Object> map = jdbcTemplate.queryForMap("SELECT version() AS version");
			logger.info("-- MySQL Version: " + map.get("version") + " --");

		} catch (EmptyResultDataAccessException e) {
			logger.info(e.getMessage());
		} catch (DataAccessException e) {
			logger.info(e.getMessage());
		}

		logger.info("We are done here.");
	}

}